@@ -1,17 +1,17 @@
 use std::path::Path;
 use std::str::FromStr;
 
+use anyhow::{Context, Result};
 use pest::iterators::Pair;
 use pest::Parser;
 use reqwest::header::{HeaderMap, HeaderName, HeaderValue};
 use reqwest::Method;
 
-use crate::errors::{FhttpError, Result};
 use crate::parsers::normal_parser::{RequestParser, Rule};
 use crate::parsers::Request;
 use crate::path_utils::RelativePath;
-use crate::request_def::body::{Body, File};
-use crate::response_handler::ResponseHandler;
+use crate::postprocessing::response_handler::ResponseHandler;
+use crate::request::body::{Body, MultipartPart};
 
 pub fn parse_str<P: AsRef<Path>, T: AsRef<str>>(
     path: P,
@@ -19,9 +19,7 @@ pub fn parse_str<P: AsRef<Path>, T: AsRef<str>>(
 ) -> Result<Request> {
     let path = path.as_ref();
     let file = RequestParser::parse(Rule::file, source.as_ref())
-        .map_err(|e| {
-            FhttpError::new(format!("failed to parse file {} {}", path.to_str().unwrap(), e.to_string()))
-        })?
+        .with_context(|| format!("failed to parse file {}", path.to_str().unwrap()))?
         .next().unwrap(); // get and unwrap the `file` rule; never fails
 
     let mut method = Method::GET;
@@ -60,7 +58,7 @@ fn parse_first_line(
     for field in element.into_inner() {
         match field.as_rule() {
             Rule::method => *method = Method::from_str(field.as_str())
-                .map_err(|_| FhttpError::new(format!("invalid method '{}'", field.as_str())))?,
+                .with_context(|| format!("invalid method '{}'", field.as_str()))?,
             Rule::url => url.push_str(field.as_str()),
             _ => unreachable!(),
         }
@@ -85,8 +83,8 @@ fn parse_header_line(
     }
 
     headers.insert(
-        HeaderName::from_str(&name).map_err(|_| FhttpError::new(format!("invalid header name: '{}'", &name)))?,
-        HeaderValue::from_str(&value).map_err(|_| FhttpError::new(format!("invalid header value: '{}'", &value)))?
+        HeaderName::from_str(&name).with_context(|| format!("invalid header name: '{}'", &name))?,
+        HeaderValue::from_str(&value).with_context(|| format!("invalid header value: '{}'", &value))?
     );
 
     Ok(())
@@ -145,11 +143,11 @@ fn plain_body_or_files(
             .map(|capture| {
                 let name = capture.get(1).unwrap().as_str().to_owned();
                 let path = capture.get(2).unwrap().as_str();
-                let path = source_path.get_dependency_path(path)?;
-                Ok(File { name, path })
+                let file_path = source_path.get_dependency_path(path)?;
+                Ok(MultipartPart::File { name, file_path, mime_str: None, })
             })
             .collect::<Result<Vec<_>>>()?;
-        Ok(Body::Files(files))
+        Ok(Body::Multipart(files))
     }
 }
 
@@ -158,6 +156,7 @@ mod parse_normal_requests {
     use std::env::current_dir;
 
     use indoc::indoc;
+    use crate::test_utils::root;
 
     use super::*;
 
@@ -472,9 +471,17 @@ mod parse_normal_requests {
         assert_eq!(
             result,
             Request::basic("GET", "http://localhost:9000/foo")
-                .file_body(&[
-                    ("partname", "resources/it/profiles.json"),
-                    ("file", "resources/it/profiles2.json"),
+                .multipart(&[
+                    MultipartPart::File {
+                        name: "partname".to_string(),
+                        file_path: root().join("resources/it/profiles.json"),
+                        mime_str: None,
+                    },
+                    MultipartPart::File {
+                        name: "file".to_string(),
+                        file_path: root().join( "resources/it/profiles2.json"),
+                        mime_str: None,
+                    },
                 ])
         );
 
